@@ -21,5 +21,5 @@ do
     else
 	echo "`date`: Data changed, resyncing..."
     fi
-done 2>&1 | tee -a /tmp/maildirsync-`date +%Y%m%d`.$$.log
+done 2>&1 | tee -a "$HOME/maildirsync-`date +%Y%m%d`.$$.log"
 
